<template>
	<div class="bbsl-common-page">
		<div class="bbsl-table-search">
			<el-form v-model="queryParam" label-width="auto">
				<el-row :gutter="10">
					<el-col :span="5">
						<el-form-item label="考核方式">
							<el-select clearable placeholder="请选择考核方式" v-model="querys[0].value">
								<el-option v-for="item in assessTypeList" :key="item.value" :label="item.name"
									:value="item.value"></el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :span="5">
						<el-form-item label="发布状态">
							<el-select clearable placeholder="请选择发布状态" v-model="querys[1].value">
								<el-option v-for="item in publishStatusList" :key="item.value" :label="item.name"
									:value="item.value"></el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :span="4">
						<el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
						<el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
					</el-col>
				</el-row>
			</el-form>
		</div>
		<div class="bbsl-table-content" ref="contentPanel">
			<div class="bbsl-btn-content" ref="btnPanel">
				<el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
				<el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
					<el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
						style="margin-left: 10px">删除</el-button>
				</el-popconfirm>
			</div>
			<el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
				:style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
				:header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
				@selection-change="handleSelectionChange">
				<el-table-column type="selection" width="55"></el-table-column>
				<el-table-column fixed type="index" width="55" label="序号"></el-table-column>
				<el-table-column min-width="120" sortable prop="assessTitle" label="考核标题" show-overflow-tooltip>
				</el-table-column>
				<el-table-column mini-width="120" sortable prop="assessType" label="考核方式" show-overflow-tooltip>
					<template #default="scope">
						{{ scope.row.assessType == '1' ? '单位考核' : '合同考核' }}
					</template>
				</el-table-column>
				<el-table-column min-width="120" sortable prop="assessYear" label="考核年度" show-overflow-tooltip>
				</el-table-column>
				<el-table-column min-width="120" sortable prop="publishStatus" label="发布状态" show-overflow-tooltip>
					<template #default="scope">
						<el-tag size="medium" type="info" v-if='scope.row.publishStatus == 0'>未发布</el-tag>
						<el-tag size="medium" type="paimary" v-if='scope.row.publishStatus == 1'>已发布</el-tag>
						<el-tag size="medium" type="success" v-if='scope.row.publishStatus == 2'>已完成</el-tag>
					</template>
				</el-table-column>
				<el-table-column prop="memo" label="备注" show-overflow-tooltip></el-table-column>
				<el-table-column prop="" label="操作" show-overflow-tooltip>
					<template #default="scope">
						<el-dropdown split-button @click="handleRelease(scope.row)" @command="toLogQuery(scope.row)"
							size="small">
							发布考核
							<el-dropdown-menu slot="dropdown">
								<el-dropdown-item command="waterStation">结束考核</el-dropdown-item>
							</el-dropdown-menu>
						</el-dropdown>
					</template>
				</el-table-column>
			</el-table>
			<el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
				@size-change="handleSizeChange" @current-change="handleCurrentChange"
				:current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
				:page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="total"></el-pagination>
		</div>
		<CheckItemDialog ref="formModal"></CheckItemDialog>
	</div>
</template>

<script>
import {
	TableMixin
} from '@/mixins/tableMixin'
import operationCheck from '@/api/device/operationCheck.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import CheckItemDialog from '@/views/Device/operationCheck/components/CheckItemDialog.vue'
export default {
	name: 'CheckItem',
	components: {
		CheckItemDialog
	},
	mixins: [TableMixin],
	data() {
		return {
			url: {
				delete: '/device/appraiseBase/'
			},
			assessTypeList: [], //考核方式字段
			publishStatusList: [], //发布状态字段
			querys: [{
				group: 'main',
				operation: 'EQUAL',
				parentGroup: '',
				property: 'assess_type_',
				relation: 'AND',
				value: ''
			},
			{
				group: 'main',
				operation: 'EQUAL',
				parentGroup: '',
				property: 'publish_status_',
				relation: 'AND',
				value: ''
			},
			{
				group: 'main',
				operation: 'NOT_IN',
				parentGroup: '',
				property: 'assess_type_',
				relation: 'AND',
				value: '3'
			},
			]
		}
	},
	created() {
		this.assessTypeList = dictUtils.getDictItemsFromCache('jxkh-khfs')
		this.publishStatusList = dictUtils.getDictItemsFromCache('fbzt')
	},
	mounted() { },
	methods: {
		// 重置
		clearQuerys() {
			this.querys[0].value = ''
			this.querys[1].value = ''
		},
		toLogQuery(row) {
			console.log(row);
			let data = {
				id: row.id,
				publishStatus: '2'
			}
			operationCheck.updatePublish(data, res => {
				if (res.state) {
					this.$notify({
						message: '结束成功',
						type: 'success',
						duration: 2000,
					})
					this.loadData(1)
				}
			})
		},
		// 获取list
		loadData(page) {
			if (page) {
				this.queryParam.pageBean.page = page
			}
			this.loading = true
			this.tableData = []
			this.queryParam.querys = []
			if (this.querys[0].value) {
				this.queryParam.querys.push(this.querys[0])
			}
			if (this.querys[1].value) {
				this.queryParam.querys.push(this.querys[1])
			}
			if (this.querys[2].value) {
				this.queryParam.querys.push(this.querys[2])
			}
			operationCheck.loadAppraiseItems(this.queryParam, res => {
				this.total = res.total
				this.tableData = res.rows
				this.$set(this.tableData)
				this.loading = false
			})
		},
		handleRelease(row) {
			let data = {
				id: row.id,
				publishStatus: '1'
			}
			operationCheck.updatePublish(data, res => {
				if (res.state) {
					this.$notify({
						message: '发布成功',
						type: 'success',
						duration: 2000,
					})
					this.loadData(1)
				}
			})
		}
	}
}
</script>
<style lang="scss" scoped>
.type-tag {
	margin: 0 2px;
}
</style>
